@@ -23,7 +23,8 @@
 
 #--------------------------------------------------------------------------------------
 """
-Lists all reservation avaialble for the current location
+Lists all the running ''clusters''. As result user will see corresponding identifiers
+(something like ''r-0d6c3467''). User can start as many ''clusters'' as he needs.
 """
 
 
@@ -86,7 +87,7 @@ def main() :
     for a_reservation in an_ec2_conn.get_all_instances() :
         an_instance = a_reservation.instances[ 0 ]
         a_status = an_instance.update()
-        if a_status == 'terminated' :
+        if a_status == 'terminated' or a_status == 'shutting-down' :
             continue
         
         print a_reservation.id
