@@ -96,7 +96,7 @@ class TRootObject :
 #--------------------------------------------------------------------------------------
 def api_version() :
 
-    return '0.5'
+    return '0.6'
 
 
 #--------------------------------------------------------------------------------------
@@ -152,9 +152,17 @@ class TSealingObject :
         "Ontains an unique seal name for each study object"
         if self._bucket == None : # in case of broken entity
             return None
-        a_seal_name = self._prefix + "_seal"
+        
+        if self.api_version() <= '0.5':
+           a_seal_name = self._prefix + "_seal"
+           return a_seal_name
+        
+        a_seal_name = self._seal_prefix
         return a_seal_name
 
+    def api_version( self ):
+        raise NotImplementedError("It is abstract method")
+    
     def prefix( self ):
         return self._prefix
         
@@ -177,29 +185,33 @@ class TSealingObject :
         return False
 
     class TIterator :
-        def __init__( self, the_bucket, the_seal_name, the_prefix ) :
+        def __init__( self, the_bucket, the_seal_name, the_prefix, the_api_version ) :
             self._bucket = the_bucket
             self._seal_name = the_seal_name
             self._prefix = _decorate_key_name( the_prefix )
+            self._api_version = the_api_version
             pass
 
         def __iter__( self ) :
             if self._bucket == None : # in case of broken entity
                 return 
+            
+            if self._api_version <= '0.5':
+               for an_entity_key in self._bucket.list( prefix = self._prefix ) :
+                   if get_key_name( an_entity_key ) == self._seal_name :
+                      continue
 
-            for an_entity_key in self._bucket.list( prefix = self._prefix ) :
-                if get_key_name( an_entity_key ) == self._seal_name :
-                    continue
-
-                yield an_entity_key
-                pass
-        
+                   yield an_entity_key
+                   pass
+            else:
+               for an_entity_key in self._bucket.list( prefix = self._prefix ) :
+                   yield an_entity_key
+                   pass
             pass
-
         pass
 
     def iterator( self ) :
-        return self.TIterator( self._bucket, self._seal_name(), self._prefix )
+        return self.TIterator( self._bucket, self._seal_name(), self._prefix, self.api_version() )
 
     def delete( self ) :
         if self._bucket == None :
@@ -269,6 +281,12 @@ def read_study_props( the_study_props, the_api_version ):
     return a_location
 
 
+#--------------------------------------------------------------------------------------
+def study_seal_prefix():
+    
+    return "seals"
+
+
 #--------------------------------------------------------------------------------------
 class TStudyObject( TSealingObject ) :
     "Represents S3 dedicated implementation of study object"
@@ -285,6 +303,8 @@ class TStudyObject( TSealingObject ) :
 
         self._api_version = the_api_version
         self._prefix = file_name_prefix( self.name() )
+        
+        self._seal_prefix = os.path.join( self.name(), study_seal_prefix(), self.name() )
         pass
     
     def root( self ) :
@@ -308,6 +328,10 @@ class TStudyObject( TSealingObject ) :
 
         return "'%s' - '%s' - %s - %s" % ( self.name(), self._api_version, self.sealed(), self._bucket )
 
+    def api_version( self ):
+
+        return self._api_version
+    
     @staticmethod
     def create( the_root_object, the_location, the_study_name ) :
         check_study_name( the_root_object._bucket, the_study_name )
@@ -457,6 +481,12 @@ def generate_uploading_dir( the_file_path ) :
     return a_working_dir
 
 
+#--------------------------------------------------------------------------------------
+def file_seal_prefix():
+    
+    return "seals/files"
+
+
 #--------------------------------------------------------------------------------------
 class TFileObject( TSealingObject ) :
     "Represents S3 dedicated implementation of file object"
@@ -474,6 +504,8 @@ class TFileObject( TSealingObject ) :
         self._file_path = the_file_path
 
         self._prefix = seed_name_prefix( self.study_name(), self.located_file() )
+        
+        self._seal_prefix = os.path.join( self.study_name(), file_seal_prefix(), self.located_file() )        
 
         pass
     
@@ -500,7 +532,7 @@ class TFileObject( TSealingObject ) :
         return self._study_object._connection
 
     def api_version( self ) :
-        return self._study_object._api_version
+        return self._study_object.api_version()
 
     def study_name( self ):
         return self._study_object.name()
