@@ -182,6 +182,20 @@ class SeedSizeMesurement :
     pass
 
 
+#--------------------------------------------------------------------------------------
+def get_testing_bucket( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, the_region ):
+    a_bucket_name = "download-seed-size"
+    import hashlib
+    a_bucket_name = hashlib.md5( a_bucket_name + the_region ).hexdigest()
+
+    from boto.s3.connection import S3Connection
+    a_conn = S3Connection( aws_access_key_id = AWS_ACCESS_KEY_ID, 
+                           aws_secret_access_key = AWS_SECRET_ACCESS_KEY )
+    a_bucket = a_conn.get_bucket( a_bucket_name )
+    
+    return a_bucket
+
+
 #--------------------------------------------------------------------------------------
 def create_testing_bucket( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, the_region  ): 
     from boto.s3.connection import S3Connection
@@ -218,7 +232,30 @@ def measure_time( the_bucket, the_filesize ):
         pass
     
     return a_time
-    
+
+
+
+#--------------------------------------------------------------------------------------
+def measure_download_time( the_bucket, the_filesize ):
+    a_key_name = str( the_filesize )
+    from boto.s3.key import Key
+    a_key = Key( the_bucket, a_key_name )
+    import tempfile
+    a_file = tempfile.mkstemp( prefix = '%d-' % the_filesize )[ 1 ]
+    import time
+    a_time = -1
+    try:
+       a_begin_time = time.time()
+       a_key.get_contents_to_filename( a_file )
+       a_end_time = time.time()
+       a_time = a_end_time - a_begin_time
+       pass
+    except Exception, exc:
+       pass
+    import os
+    os.system( 'rm %s' %a_file )
+    return a_time
+
 
 #--------------------------------------------------------------------------------------
 def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY ):
@@ -231,7 +268,7 @@ def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KE
     a_region2sum_speeds= {}
     for a_region in get_regions() :
         a_data_region = get_data_region( a_region )
-        a_region2bucket[ a_region ] = create_testing_bucket( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, a_data_region  )
+        a_region2bucket[ a_region ] = get_testing_bucket( AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KEY, a_data_region  )
         a_region2speeds[ a_region ] = list()
         a_region2sum_speeds[ a_region ] = 0
         pass
@@ -239,7 +276,7 @@ def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KE
     for i in range( the_nb_attempts ):
         for a_region in get_regions() :
             a_data_region = get_data_region( a_region )
-            a_time = measure_time( a_region2bucket[ a_region ], a_test_filesize )
+            a_time = measure_download_time( a_region2bucket[ a_region ], a_test_filesize )
             a_speed  = calculate_speed( a_test_filesize, a_time )
             a_region2speeds[ a_region ].append( a_speed )
             a_region2sum_speeds[ a_region ] = a_region2sum_speeds[ a_region ] + a_speed
@@ -252,7 +289,7 @@ def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KE
         an_averagespeed = a_region2sum_speeds[ a_region ] / float( the_nb_attempts )
         average_speed2region[ an_averagespeed ] = a_region
         print_d( " region \'%s\' : %4.0f, kbs\n"  % ( a_region, an_averagespeed ) )
-        delete_object( a_region2bucket[ a_region ] ) 
+        # delete_object( a_region2bucket[ a_region ] ) - for "upload" case
         pass
     
     an_average_speeds = average_speed2region.keys()
@@ -263,7 +300,7 @@ def search_best_region( the_nb_attempts, AWS_ACCESS_KEY_ID, AWS_SECRET_ACCESS_KE
     print_d( "\nfastest region - '%s'\n\n" % a_best_region )
 
     a_first_stats = {}
-    a_first_stats[ a_test_filesize ] = a_region2speeds[ a_region ] # further, we use this values
+    # a_first_stats[ a_test_filesize ] = a_region2speeds[ a_best_region ] # further, we use this values, only for "upload" case
     
     return a_best_region, a_first_stats 
 
